package jalview.structure;

import jalview.datamodel.DBRefSource;

public class StructureImportSettings
{
  /**
   * set to true to add derived sequence annotations (temp factor read from
   * file, or computed secondary structure) to the alignment
   */
  private static boolean visibleChainAnnotation = false;

  /**
   * Set true to predict secondary structure (using JMol for protein, Annotate3D
   * for RNA)
   */
  private static boolean predictSecStr = false;

  /**
   * Set true (with predictSecondaryStructure=true) to predict secondary
   * structure using an external service (currently Annotate3D for RNA only)
   */
  private static boolean externalSecondaryStructure = false;

  private static boolean showSeqFeatures = true;

  public static final String JMOL_PARSER = "JMolParser";

  public static final String JALVIEW_PARSER = "JalViewParser";

  public static final String MMCIF = "mmCIF";

  public static final String PDB = "PDB";

  /**
   * Determines the default file format for structure files to be downloaded
   * from the PDB sequence fetcher. Possible options include: PDB|mmCIF
   */
  private static String defaultStructureFileFormat = DBRefSource.PDB;

  /**
   * Determines the parser used for parsing PDB format file. Possible options
   * are : JMolParser|JalveiwParser
   */
  private static String defaultPDBFileParser = JMOL_PARSER;
  public static void addSettings(boolean addAlignmentAnnotations,
          boolean predictSecStr, boolean externalSecStr)
  {
    StructureImportSettings.visibleChainAnnotation = addAlignmentAnnotations;
    StructureImportSettings.predictSecStr = predictSecStr;
    StructureImportSettings.externalSecondaryStructure = externalSecStr;
    StructureImportSettings.showSeqFeatures = true;
  }

  public static boolean isVisibleChainAnnotation()
  {
    return visibleChainAnnotation;
  }

  public static void setVisibleChainAnnotation(
          boolean visibleChainAnnotation)
  {
    StructureImportSettings.visibleChainAnnotation = visibleChainAnnotation;
  }

  public static boolean isPredictSecondaryStructure()
  {
    return predictSecStr;
  }

  public static void setPredictSecondaryStructure(
          boolean predictSecondaryStructure)
  {
    StructureImportSettings.predictSecStr = predictSecondaryStructure;
  }

  public static boolean isExternalSecondaryStructure()
  {
    return externalSecondaryStructure;
  }

  public static void setExternalSecondaryStructure(
          boolean externalSecondaryStructure)
  {
    StructureImportSettings.externalSecondaryStructure = externalSecondaryStructure;
  }

  public static boolean isShowSeqFeatures()
  {
    return showSeqFeatures;
  }

  public static void setShowSeqFeatures(boolean showSeqFeatures)
  {
    StructureImportSettings.showSeqFeatures = showSeqFeatures;
  }

  public static String getDefaultStructureFileFormat()
  {
    return defaultStructureFileFormat;
  }

  public static void setDefaultStructureFileFormat(
          String defaultStructureFileFormat)
  {
    StructureImportSettings.defaultStructureFileFormat = defaultStructureFileFormat;
  }

  public static String getDefaultPDBFileParser()
  {
    return defaultPDBFileParser;
  }

  public static void setDefaultPDBFileParser(String defaultPDBFileParser)
  {
    StructureImportSettings.defaultPDBFileParser = defaultPDBFileParser;
  }

}
